@@ -97,6 +97,17 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         else:
             return False
 
+    def _do_request_no_api(self, cmd):
+        """Perform a get in the context of enabling the API."""
+        url = "https://{}:{}/{}".format(self.ip_address, self.port, cmd)
+        if self.cert:
+            resp = self._tls_session.get(url, verify=False, timeout=1, cert=self.cert)
+        else:
+            resp = self._tls_session.get(url, verify=False, timeout=1,
+                                         auth=(self.username, self.password))
+            self._tls_session.close()
+        return resp.status_code
+
     @property
     def endpoint(self):
         if self.cert:
@@ -243,27 +254,18 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         """
         # Can't use the HttpClient methods for this as the endpoint is different
         # (or has strict stipulations) when attempting to enable the API.
-        def do_request(cmd):
-            url = "https://{}:{}/{}".format(self.ip_address, self.port, cmd)
-            if self.cert:
-                resp = self._tls_session.get(url, verify=False, timeout=1, cert=self.cert)
-            else:
-                resp = self._tls_session.get(url, verify=False, timeout=1,
-                                             auth=(self.username, self.password))
-                self._tls_session.close()
-            return resp.status_code
-
         try:
-            status_code = do_request('access/set?param=enableapi&value=yes')
+            status_code = self._do_request_no_api('access/set?param=enableapi&value=yes')
             if status_code == 404:
-                do_request('progs/doconfig/enableapi/set/yes')
-                status_code = do_request('progs/status/logout')
+                self._do_request_no_api('progs/doconfig/enableapi/set/yes')
+                status_code = self._do_request_no_api('progs/status/logout')
+                print(status_code)
                 if status_code != 200:
                     raise KempTechApiException(code=status_code)
                 if health_check_api:
                     # Health check to see if API was actually enabled
                     # if it failed its usually due to auth error so raise a 401
-                    status_code = do_request('access/get?param=motd')
+                    status_code = self._do_request_no_api('access/get?param=version')
                     if status_code != 200:
                         raise KempTechApiException(code=401)
             elif status_code != 200:
