@@ -42,9 +42,9 @@ class VirtualService(BaseKempObject):
     _API_GET = "/showvs"
     _API_EXPORT = "/exportvstmplt"
     _API_LIST = "/listvs"
-    _API_TAG = "VS"
+    API_TAG = "VS"
     API_INIT_PARAMS = {
-        "ip": "VSAddress",
+        "vs": "VSAddress",
         "port": "VSPort",
         "prot": "Protocol"
     }
@@ -56,7 +56,7 @@ class VirtualService(BaseKempObject):
     _API_DEFAULT_ATTRIBUTES = {
         "status": "Status",
         "index": "Index",
-        "ip": "VSAddress",
+        "vs": "VSAddress",
         "altaddress": "AltAddress",
         "extraports": "ExtraPorts",
         "enable": "Enable",
@@ -163,16 +163,12 @@ class VirtualService(BaseKempObject):
         "needhostname",
     ]
 
-    @property
-    def rs(self):
-        return {int(rs.rsindex): rs for rs in self.get_real_servers()}
-
-    def __init__(self, loadmaster_info, ip_or_index, port=80, prot="tcp",
+    def __init__(self, loadmaster_info, vs, port=80, prot="tcp",
                  is_sub_vs=False):
         """Construct VirtualService object.
 
         :param loadmaster_info: The loadmaster dict with the endpoint params.
-        :param ip_or_index: IP or index of the VS. When creating a subvs you
+        :param vs: IP or index of the VS. When creating a subvs you
                must pass the index and set the is_sub_vs flag to true in order
                for createsubvs to behave correctly. The index will be
                overwritten with the index of the newly created subvs on save().
@@ -186,6 +182,8 @@ class VirtualService(BaseKempObject):
         self.subvs_data = None
         self.subvs_entries = []
         self.real_servers = []
+        self.sslrewrite = None
+        self.certfile = None
 
         self._waf = False
         self._esp = False
@@ -193,16 +191,15 @@ class VirtualService(BaseKempObject):
 
         if not is_sub_vs:
             # Skip validation when it is a subvs as they do not have ip/port
-            self.vs = ip_or_index
+            self.vs = vs
             self.port = port
             self.prot = prot
 
-            validate_ip(ip_or_index)
+            validate_ip(vs)
             validate_port(port)
             validate_protocol(prot)
         else:
-            self.index = ip_or_index
-            self.vs = ip_or_index
+            self.index = self.vs = vs
 
         self.cert = loadmaster_info.get("cert")
         try:
@@ -225,6 +222,10 @@ class VirtualService(BaseKempObject):
             return 'Virtual Service {} {}:{} on LoadMaster {}'.format(
                 self.prot.upper(), self.vs, self.port, self.ip_address)
 
+    @property
+    def rs(self):
+        return {int(rs.rsindex): rs for rs in self.get_real_servers()}
+
     def to_api_dict(self):
         api = super(VirtualService, self).to_api_dict()
 
@@ -250,7 +251,11 @@ class VirtualService(BaseKempObject):
     def _get_base_parameters(self):
         """Returns the bare minimum VS parameters. IP, port and protocol"""
         if self.index is None:
-            return super(VirtualService, self)._get_base_parameters()
+            return {
+                "vs": self.vs,
+                "port": self.port,
+                "prot": self.prot,
+            }
         else:
             return {"vs": self.index}
 
@@ -266,25 +271,6 @@ class VirtualService(BaseKempObject):
             "enable": self.subvs_data['Enable']
         }
 
-    @property
-    def access_info(self):
-        if self.index is None:
-            return {
-                "endpoint": self.endpoint,
-                "cert": self.cert,
-                "ip_address": self.ip_address,
-                "vs": self.vs,
-                "port": self.port,
-                "prot": self.prot,
-            }
-        else:
-            return {
-                "endpoint": self.endpoint,
-                "cert": self.cert,
-                "ip_address": self.ip_address,
-                "vs": self.index,
-            }
-
     @property
     def checkuse1_1(self):
         """This property exists because . can not be in a variable name.
@@ -303,19 +289,17 @@ class VirtualService(BaseKempObject):
 
     def save(self, update=False):
         # Parse certfile field if SSL acceleration is enabled
-        try:
-            if self.sslacceleration == "Y":
+        if hasattr(self, "sslacceleration") and self.sslacceleration == "Y":
+            if hasattr(self, "certfile"):
                 if isinstance(self.certfile, list):
                     self.certfile = " ".join(self.certfile)
                 if isinstance(self.certfile, str):
                     self.certfile = self.certfile.strip()
-            else:
-                self.certfile = None
-        except AttributeError:
+        else:
             self.certfile = None
 
         # Clear the persist timeout if persistence is not used
-        if self.persist is None:
+        if hasattr(self, "persist") and self.persist is None:
             self.persisttimeout = None
 
         if not update:
@@ -330,8 +314,9 @@ class VirtualService(BaseKempObject):
                 data = get_data(response)
                 new_subvs_entries, subvs_data = get_sub_vs_list_from_data(data)
                 s = set(existing_subvs_entries)
-                created_subvs_id = [x
-                                    for x in new_subvs_entries
+                # Subtracts the existing ID's from the new IDs to know what ID
+                # to use when populating the self's attributes
+                created_subvs_id = [x for x in new_subvs_entries
                                     if x not in s]
                 newly_created_vs_params = {"vs": created_subvs_id}
                 self.subvs_data = subvs_data[created_subvs_id[0]]
@@ -513,8 +498,10 @@ class VirtualService(BaseKempObject):
             }
 
             try:
-                self.sslrewrite = sslrewrite[self.sslrewrite]
-            except KeyError:
+                # Try casting to an int in the case that the end user passes
+                # the string version of the int.
+                self.sslrewrite = sslrewrite[int(self.sslrewrite)]
+            except (KeyError, TypeError):
                 self.sslrewrite = None
 
             #
@@ -573,7 +560,7 @@ class RealServer(BaseKempObject):
     _API_DELETE = "/delrs"
     _API_GET = "/showrs"
     _API_LIST = "/showvs"
-    _API_TAG = "Rs"
+    API_TAG = "Rs"
     API_INIT_PARAMS = {
         "ip": "Addr",
         "port": "Port"
@@ -837,7 +824,7 @@ class Rule(BaseKempObject):
         """Populate object instance with standard defaults"""
         # Get data from inside tag
         # Tag is unknown since different rule types have
-        # different tag names. The generic code using _API_TAG
+        # different tag names. The generic code using API_TAG
         # isn't usable in this case.
         dictionary = dictionary.popitem()[1]
 
@@ -867,14 +854,6 @@ class Sso(BaseKempObject):
             "domain": self.name
         }
 
-    @property
-    def access_info(self):
-        return {
-            "endpoint": self.endpoint,
-            "ip_address": self.ip_address,
-            "domain": self.name
-        }
-
     def save(self, update=False):
         if not update:
             response = self._get("/adddomain", self._get_base_parameters())
@@ -926,7 +905,7 @@ class Fqdn(BaseKempObject):
     _API_DELETE = "/delfqdn"
     _API_GET = "/showfqdn"
     _API_LIST = "/listfqdns"
-    _API_TAG = "fqdn"
+    API_TAG = "fqdn"
     API_INIT_PARAMS = {
         "fqdn": "FullyQualifiedDomainName"
     }
@@ -1021,13 +1000,13 @@ class Fqdn(BaseKempObject):
         try:
             response = self._get(self._API_LIST, fqdn)
             data = get_data(response)
-            xml_object = data["fqdn"].get(self._API_TAG, [])
+            xml_object = data["fqdn"].get(self.API_TAG, [])
         except KempTechApiException:
             xml_object = []
 
         obj_list = []
 
-        # If there is no _API_TAG key, build will fail with a
+        # If there is no API_TAG key, build will fail with a
         # ValidationError, which is the best we can do for now
         # (without changing the upstream code and raising an
         # exception earlier, possibly retrying)
@@ -1056,7 +1035,7 @@ class Site(BaseKempObject):
     _API_DELETE = "/delmap"
     _API_GET = "/showfqdn"
     _API_LIST = "/showfqdn"
-    _API_TAG = "Map"
+    API_TAG = "Map"
     API_INIT_PARAMS = {
         "ip": "IPAddress"
     }
@@ -1193,7 +1172,7 @@ class Site(BaseKempObject):
         if is_successful(response):
             response = self._get(self._API_GET, self._get_base_parameters())
             data = get_data(response)
-            maps = data["fqdn"].get(self._API_TAG, {})
+            maps = data["fqdn"].get(self.API_TAG, {})
 
             if not isinstance(maps, list):
                 maps = [maps]
@@ -1222,7 +1201,7 @@ class Site(BaseKempObject):
         if is_successful(response):
             response = self._get(self._API_GET, self._get_base_parameters())
             data = get_data(response)
-            maps = data["fqdn"].get(self._API_TAG, {})
+            maps = data["fqdn"].get(self.API_TAG, {})
 
             if not isinstance(maps, list):
                 maps = [maps]
@@ -1289,7 +1268,6 @@ class Site(BaseKempObject):
             raise KempTechApiException(get_error_msg(response))
 
     def set_locations(self, locations):
-        print("Removing existing")
 
         # Remove all existing locations
         for location in self.continent or []:
@@ -1301,7 +1279,6 @@ class Site(BaseKempObject):
         for location in self.customlocation or []:
             self.remove_location(location['name'], False, True)
 
-        print("Adding replacements")
         # Add new set of locations
         for location in locations.get("continent", []):
             self.add_location(location['code'], True, False)
@@ -1352,7 +1329,7 @@ class Cluster(BaseKempObject):
     _API_DELETE = "/delcluster"
     _API_GET = "/showcluster"
     _API_LIST = "/listclusters"
-    _API_TAG = "cluster"
+    API_TAG = "cluster"
     API_INIT_PARAMS = {
         "ip": "IPAddress",
         "name": "Name"
@@ -1419,7 +1396,7 @@ class Range(BaseKempObject):
     _API_DELETE = "/delip"
     _API_GET = "/showip"
     _API_LIST = "/listips"
-    _API_TAG = "IPAddress"
+    API_TAG = "IPAddress"
     API_INIT_PARAMS = {
         "ip": "IPAddress",
         "mask": "Mask"
@@ -1496,14 +1473,6 @@ class Range(BaseKempObject):
             "ip": self.ip
         }
 
-    @property
-    def access_info(self):
-        return {
-            "endpoint": self.endpoint,
-            "ip_address": self.ip_address,
-            "ip": self.ip
-        }
-
     def save(self, update=False):
         if not update:
             base_parameters = {
@@ -1540,7 +1509,6 @@ class Range(BaseKempObject):
 
         if self.country is not None:
             parameters.update(self._get_base_parameters())
-            print(parameters)
             response = self._get(self._API_ADD_CC, parameters)
         else:
             response = self._get(self._API_DEL_CC, self._get_base_parameters())
@@ -1590,14 +1558,6 @@ class CustomLocation(BaseKempObject):
             "location": self.name
         }
 
-    @property
-    def access_info(self):
-        return {
-            "endpoint": self.endpoint,
-            "ip_address": self.ip_address,
-            "clname": self.name
-        }
-
     def save(self, update=False):
         if not update:
             response = self._get("/addcustomlocation",
@@ -1701,7 +1661,7 @@ class Interface(BaseKempObject):
     _API_LIST = "/stats"
     _API_ADD_ADDRESS = "/addadditional"
     _API_DELETE_ADDRESS = "/deladditional"
-    _API_TAG = "Interface"
+    API_TAG = "Interface"
     _API_LIST_TAG = "Network"
     API_INIT_PARAMS = {
         "interface": "Id"
@@ -1784,7 +1744,7 @@ class Interface(BaseKempObject):
         except KempTechApiException:
             xml_object = []
 
-        # If there is no _API_TAG key, build will fail with a
+        # If there is no API_TAG key, build will fail with a
         # ValidationError, which is the best we can do for now
         # (without changing the upstream code and raising an
         # exception earlier, possibly retrying)
