@@ -1,3 +1,4 @@
+from itertools import chain
 from unittest import skip
 
 from nose.tools import (
@@ -20,7 +21,7 @@ sentinel = mock.sentinel
 from python_kemptech_api import models
 from python_kemptech_api import utils
 from python_kemptech_api.objects import VirtualService
-from python_kemptech_api.models import LoadMaster
+from python_kemptech_api.models import LoadMaster, BaseKempAppliance
 import python_kemptech_api.exceptions as exceptions
 
 
@@ -413,16 +414,21 @@ class TestLmApiWrapperCalls:
             self.lm.enable_api()
 
     def test_old_enable_api_url(self):
-        resp = mock.MagicMock()
-        #resp.status_code = mock.
-        #resp.status_code = mock.PropertyMock(side_effect=[401, 200, 200])
-        #resp.status_code.side_effect = [401, 200, 200]
-        self.get.return_value = resp
-        self.lm.enable_api(True)
+        with patch.object(BaseKempAppliance, "_do_request_no_api") as do_request:
+            do_request.side_effect = [404, 200, 200, 200]
+            self.lm.enable_api(True)
 
     def test_old_enable_api_url_wrong_credentials(self):
-        pass
-        #self.lm.enable_api(True)
+        with patch.object(BaseKempAppliance, "_do_request_no_api") as do_request:
+            with assert_raises(exceptions.KempTechApiException):
+                do_request.side_effect = [404, 200, 200, 404]
+                self.lm.enable_api(True)
+
+    def test_old_enable_api_url_logout_fails(self):
+        with patch.object(BaseKempAppliance, "_do_request_no_api") as do_request:
+            with assert_raises(exceptions.KempTechApiException):
+                do_request.side_effect = [404, 200, 400]
+                self.lm.enable_api(True)
 
     def test_enable_api_exception(self):
         with patch.object(LoadMaster, "get_parameter") as get_parameter:
